#include "PackageTableDescribeDialog.h"
#include <QtGui/QHBoxLayout>
#include <QtGui/QVBoxLayout>
#include <QtGui/QGridLayout>
#include <QtGui/QPushButton>
#include "HSeparator.h"
#include <QtGui/QLabel>
#include "Fonts.h"
#include <QtGui/QPushButton>

PackageTable::Describe::Dialog::Dialog(QWidget*  parent)
   : QDialog(parent),
     descrWidget(NULL)
{
   setWindowTitle(tr("NUU Package Description"));

   setAttribute(Qt::WA_ShowModal, true);

   QVBoxLayout*  mainLayout  = new QVBoxLayout;
                 descrLayout = new QHBoxLayout;
   mainLayout->addLayout(descrLayout);

   QHBoxLayout*  buttonsLayout = new QHBoxLayout;
   QPushButton*  closeButton   = new QPushButton(tr("Close"), this);
   buttonsLayout->addStretch(1);
   buttonsLayout->addWidget(closeButton);
   connect(closeButton, SIGNAL(clicked()), this, SLOT(accept()));
   mainLayout->addLayout(buttonsLayout);

   setLayout(mainLayout);
}

void PackageTable::Describe::Dialog::config(YumIO*                 yumIO,
                                            const Package::Entry&  entry,
                                            YumConfIO*             yumConfIO)
{
                 descrWidget = new QWidget(this);
   QVBoxLayout*  layout      = new QVBoxLayout;

   QLabel*  headerLabel = new QLabel(entry.name, descrWidget);
   headerLabel->setFont(Fonts::makeHeader(headerLabel->font()));
   headerLabel->setAlignment(Qt::AlignHCenter);
   layout->addWidget(headerLabel);

   layout->addWidget(new HSeparator(descrWidget));

   instances.append(new Instance::Area(layout, yumIO, entry, yumConfIO, 
                                       /* primary => */ true));

   Package::Entry*  extra = entry.next;
   for (; extra != NULL; extra = extra->next) {
      layout->addWidget(new HSeparator(descrWidget));
      
      instances.append(new Instance::Area(layout, yumIO, *extra, yumConfIO,
                                          /* primary => */ false));
   }
   
   descrWidget->setLayout(layout);
   descrLayout->addWidget(descrWidget);
}

void PackageTable::Describe::Dialog::setVisible(bool visible)
{
   if (!visible) {
      descrLayout->removeWidget(descrWidget);
      delete descrWidget;
      descrWidget = NULL;
      qDeleteAll(instances.begin(), instances.end());
      instances.clear();
   }

   QDialog::setVisible(visible);
}
